# Return if not interactive
[[ $- != *i* ]] && return

# Advanced bashcompletion
[ -f /usr/share/bash-completion/bash_completion ] && source /usr/share/bash-completion/bash_completion

# History Control
export HISTSIZE=20000
export HISTCONTROL=ignoreboth,erasedups
shopt -s histappend
export PROMPT_COMMAND="history -a; history -n; $PROMPT_COMMAND"

# Shell Options

# Shell options
shopt -s cdspell    # Correct minor typos in cd directories
shopt -s dirspell   # Correct minor typos in globbing
shopt -s autocd     # Change to directories without typing cd
shopt -s extglob    # Enable extended globbing
shopt -u mailwarn   # Don't notify for mails
stty -ixon          # Disable Strg+s
set -o notify       # Notify on completion of background jobs

# Prompt
if [[ $UID -eq 0 ]]
then
	PS1='\[\e[1;31m\]\u\[\e[1;37m\]@\[\e[1;31m\]\h\[\e[m\] \[\e[1;36m\]\w\[\e[m\] \[\e[1;37m\]\$\[\e[m\] '
else
	PS1='\[\e[1;32m\]\u\[\e[1;37m\]@\[\e[1;32m\]\h\[\e[m\] \[\e[1;36m\]\w\[\e[m\] \[\e[1;37m\]\$\[\e[m\] '
fi

# Show if we are on an SSH-Connection
[[ -n "$SSH_CONNECTION" ]] && PS1="\[\e[1;37m\][SSH] $PS1"

# Defaults
export EDITOR=vim
export VISUAL=vim

# Colors
export LESS_TERMCAP_mb=$'\E[02;31m'
export LESS_TERMCAP_md=$'\E[01;31m'
export LESS_TERMCAP_me=$'\E[0m'
export LESS_TERMCAP_se=$'\E[0m'                           
export LESS_TERMCAP_so=$'\E[01;44;33m'                                 
export LESS_TERMCAP_ue=$'\E[0m'
export LESS_TERMCAP_us=$'\E[01;32m'

# Colors for ls
LS_COLORS='rs=0:di=01;36:ln=44;01;36:mh=44;37:pi=40;33:so=01;35:do=01;35:bd=40;33;01:cd=40;33;01:or=40;31;01:su=37;41:sg=30;43:ca=30;41:tw=30;42:ow=34;42:st=37;44:ex=01;32:*.tar=01;31:*.tgz=01;31:*.arj=01;31:*.taz=01;31:*.lzh=01;31:*.lzma=01;31:*.zip=01;31:*.z=01;31:*.Z=01;31:*.dz=01;31:*.gz=01;31:*.bz2=01;31:*.bz=01;31:*.tbz2=01;31:*.tz=01;31:*.deb=01;31:*.rpm=01;31:*.jar=01;31:*.rar=01;31:*.ace=01;31:*.zoo=01;31:*.cpio=01;31:*.7z=01;31:*.rz=01;31:*.jpg=01;35:*.jpeg=01;35:*.gif=01;35:*.bmp=01;35:*.pbm=01;35:*.pgm=01;35:*.ppm=01;35:*.tga=01;35:*.xbm=01;35:*.xpm=01;35:*.tif=01;35:*.tiff=01;35:*.png=01;35:*.svg=01;35:*.svgz=01;35:*.mng=01;35:*.pcx=01;35:*.mov=01;35:*.mpg=01;35:*.mpeg=01;35:*.m2v=01;35:*.mkv=01;35:*.ogm=01;35:*.mp4=01;35:*.m4v=01;35:*.mp4v=01;35:*.vob=01;35:*.qt=01;35:*.nuv=01;35:*.wmv=01;35:*.asf=01;35:*.rm=01;35:*.rmvb=01;35:*.flc=01;35:*.avi=01;35:*.fli=01;35:*.flv=01;35:*.gl=01;35:*.dl=01;35:*.xcf=01;35:*.xwd=01;35:*.yuv=01;35:*.axv=01;35:*.anx=01;35:*.ogv=01;35:*.ogx=01;35:*.aac=00;36:*.au=00;36:*.flac=00;36:*.mid=00;36:*.midi=00;36:*.mka=00;36:*.mp3=00;36:*.mpc=00;36:*.ogg=00;36:*.ra=00;36:*.wav=00;36:*.axa=00;36:*.oga=00;36:*.spx=00;36:*.xspf=00;36:';
export LS_COLORS

# Color for grep
export GREP_COLOR="1;33"

# Aliases
alias ls='ls --color=auto'
alias grep='grep --color=auto'
alias df='(echo "Device Size Used Avail Usage% Mountpoint"; df -hP -x tmpfs -x devtmpfs 2>&1 | egrep -v "Dateisystem|/mnt/data/homes/|rootfs") |column -t'
